@@ -15,7 +15,7 @@
 KBlocksGraphics::KBlocksGraphics(const KgTheme *theme)
 {
     m_renderer = new QSvgRenderer(theme->graphicsPath());
-    readThemeValues();
+    readThemeValues(theme);
 }
 
 KBlocksGraphics::~KBlocksGraphics()
@@ -32,44 +32,12 @@ bool KBlocksGraphics::loadTheme(const KgTheme *theme)
     }
     //clear the cache or pixmaps from the old theme will be returned
     //QPixmapCache::clear();
-    readThemeValues();
+    readThemeValues(theme);
+
     return true;
 }
 
-void KBlocksGraphics::adjustForSize(const QSize &newsize)
-{
-    Q_UNUSED(newsize)
-    //Reset our values
-    readThemeValues();
-
-    return;
-
-    /*
-    double aspectratio;
-    double nw = newsize.width();
-    double nh = newsize.height();
-
-    double origw = m_View_Size_Width;
-    double origh = m_View_Size_Height;
-
-    if ((origw/origh)>(nw/nh)) {
-        //space will be left on height, use width as limit
-        aspectratio = nw/origw;
-    } else {
-        aspectratio = nh/origh;
-    }
-    //qCDebug(KBGraphics) << aspectratio;
-    m_Block_Size = (int) (aspectratio*(qreal)m_Block_Size);
-    m_View_Size_Width = (int) (aspectratio*(double)m_View_Size_Width);
-    m_View_Size_Height = (int) (aspectratio*(double)m_View_Size_Height);
-    m_PlayArea_OffsetPoint_X = (int) (aspectratio*(qreal)m_PlayArea_OffsetPoint_X);
-    m_PlayArea_OffsetPoint_Y = (int) (aspectratio*(qreal)m_PlayArea_OffsetPoint_Y);
-    m_PreviewArea_CenterPoint_X = (int) (aspectratio*(qreal)m_PreviewArea_CenterPoint_X);
-    m_PreviewArea_CenterPoint_Y = (int) (aspectratio*(qreal)m_PreviewArea_CenterPoint_Y);
-    */
-}
-
-void KBlocksGraphics::readThemeValues()
+void KBlocksGraphics::readThemeValues(const KgTheme *theme)
 {
     //Extract values from SVG elements
     QRectF bounds;
@@ -86,5 +54,14 @@ void KBlocksGraphics::readThemeValues()
     bounds = m_renderer->boundsOnElement(QStringLiteral("NEXTPIECE_AREA"));
     m_PreviewArea_CenterPoint_X = bounds.center().x();
     m_PreviewArea_CenterPoint_Y = bounds.center().y();
+
+    const QString backgroundLocation = theme->customData(QStringLiteral("BackgroundLocation"), QStringLiteral("Stretch"));
+    if(backgroundLocation == QStringLiteral("Stretch")) {
+        m_BackgroundLocation = BackgroundLocation::Stretch;
+    } else if(backgroundLocation == QStringLiteral("TopLeft")) {
+        m_BackgroundLocation = BackgroundLocation::TopLeft;
+    } else if(backgroundLocation == QStringLiteral("Center")) {
+        m_BackgroundLocation = BackgroundLocation::Center;
+    }
 }
 
