@@ -22,8 +22,7 @@ public:
 
 public:
     bool loadTheme(const KgTheme *theme) override;
-    void readThemeValues() override;
-    void adjustForSize(const QSize &newsize) override;
+    void readThemeValues(const KgTheme *theme) override;
     QSvgRenderer *renderer() const override
     {
         return m_renderer;
