@@ -12,6 +12,7 @@
 #include <QGraphicsView>
 
 class SceneInterface;
+class KgTheme;
 
 class KBlocksView : public QGraphicsView
 {
@@ -27,6 +28,9 @@ Q_SIGNALS:
 public Q_SLOTS:
     void settingsChanged();
 
+public:
+    void loadTheme(const KgTheme *theme);
+
 protected:
     void focusInEvent(QFocusEvent *event) override;
     void focusOutEvent(QFocusEvent *event) override;
