@@ -13,6 +13,8 @@ enum class Sound {
     BlockRemove
 };
 
+class KgTheme;
+
 class SoundInterface
 {
 public:
@@ -20,7 +22,7 @@ public:
     virtual ~SoundInterface() = default;
 
 public:
-    virtual bool loadTheme(const QString &) = 0;
+    virtual bool loadTheme(const KgTheme *) = 0;
     virtual void setSoundsEnabled(bool) = 0;
     virtual void playSound(Sound) = 0;
 };
